powered by
Contains dailies and totals of cases, recoveries, and deaths from the COVID-19 outbreak in India from January 30 to September 21 of 2020.
covid19
An object of class data.frame with 236 rows and 7 columns.
data.frame
Date as a character string
Daily confirmed cases as an integer vector
Total confirmed cases upto current date as an integer vector
Daily recovered cases an an integer vector
Daily deceased cases as an integer vector
Total deceased cases upto current date as an integer vector
# NOT RUN { covid19 head(covid19) tail(covid19) # }
Run the code above in your browser using DataLab